package com.lantone.qc.kernel.catalogue;

import com.google.common.collect.Maps;
import com.lantone.qc.kernel.util.CatalogueUtil;
import com.lantone.qc.pub.model.InputInfo;
import com.lantone.qc.pub.model.OutputInfo;
import com.lantone.qc.pub.util.StringUtil;
import lombok.extern.slf4j.Slf4j;

import java.text.ParseException;
import java.util.Map;

/**
 * @ClassName : QCCatalogue
 * @Description : 质控条目解析
 * @Author : 楼辉荣
 * @Date: 2020-03-04 11:24
 */
@Slf4j
public class QCCatalogue {

    protected String status = "-1";
    protected String info = "";
    private Map<String, String> resultDetail = Maps.newHashMap();
    private String className = this.getClass().getSimpleName();

    public QCCatalogue() {
        CatalogueUtil.qcCatalogueMap.put(className, this);
    }

    public void execute(InputInfo inputInfo, OutputInfo outputInfo) {
        if (outputInfo.getResult().get(className) != null) {
            return;
        }
        precondExecute(inputInfo, outputInfo);
        try {
            start(inputInfo, outputInfo);
        } catch (Exception e) {
            propertiesClear();
            log.info(e.getMessage());
        }
        insertOpt(outputInfo);
    }

    protected void start(InputInfo inputInfo, OutputInfo outputInfo) throws ParseException {
    }

    private void insertOpt(OutputInfo outputInfo) {
        resultDetail.put("info", info);
        resultDetail.put("status", status);
        outputInfo.getResult().put(className, resultDetail);
        propertiesClear();
    }

    private void propertiesClear() {
        status = "-1";
        info = "";
    }

    //前置条件运行
    private void precondExecute(InputInfo inputInfo, OutputInfo outputInfo) {
        Map<String, String> catalogueMap = inputInfo.getInputCatalogueMap().get(className);
        if (catalogueMap == null) {
            return;
        }
        String precond = catalogueMap.get("precond");
        if (StringUtil.isBlank(precond)) {
            return;
        }
        for (String i : precond.split(",")) {
            QCCatalogue qCCatalogue = CatalogueUtil.qcCatalogueMap.get(i);
            if (qCCatalogue != null) {
                qCCatalogue.execute(inputInfo, outputInfo);
            }
        }
    }

}